//***************************************************************************//
//*                                                                         *//
//* Unit:    xml_docType                                                    *//
//* Author:  Dushkin R.V.                                                   *//
//* Date:    29.04.01                                                       *//
//*                                                                         *//
//*  This module provides description of the class, which represents XML's  *//
//* DOCTYPE, and if needed the structure of DTD section.                    *//
//*                                                                         *//
//***************************************************************************//
unit xml_docType;

//-[ INTERFACE ]---------------------------------------------------------------
interface

uses
  xml_types;

type TXMLDocType = class (TObject)
  private
    fDocTypeDefinition : String;

  public
    constructor Create;
    destructor Destroy; override;

    procedure SaveToFile (var where : TextFile);

    function ParseString (var iStr : String) : TXMLErrorCode;

  published
    property DocTypeDefinition : String read fDocTypeDefinition write fDocTypeDefinition;

end;

//-[ IMPLEMENTATION ]----------------------------------------------------------
implementation

constructor TXMLDocType.Create;
begin
  inherited Create;
  fDocTypeDefinition := '';
end;

destructor TXMLDocType.Destroy;
begin
  inherited Destroy;
end;

{ DONE 5 -oDushkin R.V. -cFunction : Implement ParseString function, which must delete <!DOCTYPE ... !> section from the XML-document. }
function TXMLDocType.ParseString (var iStr : String) : TXMLErrorCode;
begin
  Result := ecOk;
  fDocTypeDefinition := Copy (iStr, 1, Pos ('>', iStr));
  Delete (iStr, 1, Pos ('>', iStr));
end;

procedure TXMLDocType.SaveToFile (var where : TextFile);
begin
  WriteLn (where, fDocTypeDefinition);
end;

//-[ END ]---------------------------------------------------------------------
end.
